reddit: the front page of the internet
Description: Reddit is a network of communities based on people's interests. Find communities you're interested in, and become part of an online community!

View
Sort
hot
new
top
rising
Trending today
Popular posts
10.4k
• Posted by 4 hours ago
2

### Tsai Ing-wen says Beijing must face reality that Taiwan is ‘an independent country already’

scmp.com/news/c...
10.4k
484 comments
•
promoted • Posted by 26 days ago
Comments are locked

### Create intelligent apps using powerful data and AI services. Try Azure free.

azure.microsoft.com Learn More
•
comment
21.0k
• Posted by 6 hours ago

### Turtle Enjoying A Nice Morning Stretch

gfycat.com/mistyd...
21.0k
302 comments
32.7k
• Posted by 11 hours ago
2

### You've been granted a wish, but only if it's one you had as a child. What is your wish?

32.7k
13.2k comments
7.7k
• Posted by 18 hours ago
2 7 18

### New quest on osiris

Megathread
7.7k
3.4k comments
84.0k
• Posted by 18 hours ago
4

### Marijuana use among college students has been trending upward for years, but in states that have legalized recreational marijuana, use has jumped even higher. After legalization, however, students showed a greater drop in binge drinking than their peers in states where marijuana is not legal.

Health
today.oregonstate.edu/news/c...
84.0k
3.3k comments
16.2k
• Posted by 4 hours ago

### A Good Warning

16.2k
261 comments

View all
Sports News Gaming Aww
Reddit Premium
The best Reddit experience, with monthly Coins

## Trending Communities

r/TheOutsider

5.5k members

r/neartoptalent

39.2k members

r/WhiteHouseDinners

28.6k members

r/makeupartists

3.7k members

r/UnexplainedPhotos

82.6k members

Popular Communities
Gaming
Sports
TV
Travel
Health & Fitness
Fashion
Reddit
about careers press advertise blog
Using Reddit
help Reddit App Reddit coins Reddit premium Reddit gifts Communities Top Posts
Terms | Content policy | Privacy policy | Mod policy
Reddit Inc © 2020. All rights reserved